From: Andres Freund <andres@anarazel.de>
To: Andreas Joseph Krogh <andreas@visena.com>
Cc: pgsql-hackers@lists.postgresql.org
Subject: Re: Query is over 2x slower with jit=on
Date: Wed, 18 Apr 2018 08:50:55 -0700
Message-ID: <20180418155055.gawfkerzvy5rxpxe@alap3.anarazel.de> (raw)
In-Reply-To: <VisenaEmail.24.e60072a07f006130.162d95c3e17@tc7-visena>
References: <VisenaEmail.24.e60072a07f006130.162d95c3e17@tc7-visena>
On 2018-04-18 17:35:31 +0200, Andreas Joseph Krogh wrote:
> With jit=on:
> https://explain.depesz.com/s/vYB
> Planning Time: 0.336 ms
> JIT:
> Functions: 716
> Generation Time: 78.404 ms
> Inlining: false
> Inlining Time: 0.000 ms
> Optimization: false
> Optimization Time: 43.916 ms
> Emission Time: 600.031 ms
Any chance this is a debug LLVM build?
> What's the deal with jit making it slower?
JIT has cost, and sometimes it's not beneficial. Here our heuristics
when to JIT appear to be a bit off. In the parallel world it's worse
because the JITing is duplicated for parallel workers atm.
Greetings,
Andres Freund
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-hackers@postgresql.org
Cc: andres@anarazel.de, andreas@visena.com, pgsql-hackers@lists.postgresql.org
Subject: Re: Query is over 2x slower with jit=on
In-Reply-To: <20180418155055.gawfkerzvy5rxpxe@alap3.anarazel.de>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox